package com.smartadserver.android.sasnewsreader;

import java.io.InputStream;
import java.net.HttpURLConnection;
import java.net.URL;
import java.text.DateFormat;
import java.util.ArrayList;
import java.util.Date;

import org.xmlpull.v1.XmlPullParser;
import org.xmlpull.v1.XmlPullParserFactory;

import android.os.AsyncTask;
import android.text.Html;
import android.text.Spanned;
import android.text.style.ImageSpan;

import com.smartadserver.android.library.model.SASNativeAdManager;

public class FetchDataTask extends AsyncTask<String, String, ArrayList<ListElement>> {
	
	public static String TAG = "FetchDataTask";
	
	private SASNativeAdManager[] mNativeAdManagerPool;
	
	private enum RSSXMLTag {
		TITLE, LINK, IMAGE, ENCLOSURE, DESCRIPTION, DATE, IGNORETAG;
	}


	/**
	 *
	 * @param nativeAdManagerPool
	 */
	public FetchDataTask(SASNativeAdManager[] nativeAdManagerPool) {
		mNativeAdManagerPool = nativeAdManagerPool;
	}

	@Override
	protected ArrayList<ListElement> doInBackground(String... params) {
		
		
		// initialize the list of elements
		ArrayList<ListElement> elementList = new ArrayList<ListElement>();
		int elementCount = 0;
		
		// insert ad every 'adInterleave' content elements
		int adInterleave = 7;
		int adIndex = 0;
		
		DateFormat dateFormat = DateFormat.getTimeInstance();
		
		try {
			URL url = new URL(params[0]);
			InputStream is = null;
			HttpURLConnection connection = (HttpURLConnection) url
					.openConnection();
			connection.setReadTimeout(10 * 1000);
			connection.setConnectTimeout(10 * 1000);
			connection.setRequestMethod("GET");
			connection.setDoInput(true);
			connection.connect();
			int response = connection.getResponseCode();
//			Log.d("debug", "The response is: " + response);
			is = connection.getInputStream();

			// parse xml after getting the data
			XmlPullParserFactory factory = XmlPullParserFactory.newInstance();
			factory.setNamespaceAware(true);
			XmlPullParser xpp = factory.newPullParser();
			xpp.setInput(is, null);
			
			int eventType = xpp.getEventType();
			
			ListElement currentElement = null;
			RSSXMLTag currentTag = null;
			// now parse xml
			while (eventType != XmlPullParser.END_DOCUMENT) {
				if (eventType == XmlPullParser.START_DOCUMENT) {

				} else if (eventType == XmlPullParser.START_TAG) {
					if (xpp.getName().equals("item")) {
						currentElement = new ListElement();
						currentTag = RSSXMLTag.IGNORETAG;
					} else if (xpp.getName().equals("title")) {
						currentTag = RSSXMLTag.TITLE;
					} else if (xpp.getName().equals("link")) {
						currentTag = RSSXMLTag.LINK;
					} else if (xpp.getName().equals("image")) {
						currentTag = RSSXMLTag.IMAGE;
					}
					else if (xpp.getName().equals("enclosure")) {
						currentTag = RSSXMLTag.ENCLOSURE;
						String mediaUrl = xpp.getAttributeValue(null, "url");
						String mediaType = xpp.getAttributeValue(null, "type");
						if ("image/jpeg".equals(mediaType)) {
							currentElement.thumbnailUrl = mediaUrl;
						}
					}
					else if (xpp.getName().equals("description")) {
						currentTag = RSSXMLTag.DESCRIPTION;
					}
					
					else if (xpp.getName().equals("pubDate")) {
						currentTag = RSSXMLTag.DATE;
					}
				} else if (eventType == XmlPullParser.END_TAG) {
					if (xpp.getName().equals("item")) {
						// format the data here, otherwise format data in
						// Adapter
						try {
							Date postDate = dateFormat.parse(currentElement.details);
							currentElement.details = dateFormat.format(postDate);
						} catch (Exception e) {
							// unparseable date, use string directly
						}
						elementList.add(currentElement);
						elementCount++;
						
						// insert ad here if
						if (elementCount%adInterleave == 0 && adIndex < mNativeAdManagerPool.length) {
							AdElement adElement= new AdElement(mNativeAdManagerPool[adIndex]);
							elementList.add(adElement);
							adIndex++;
						}
						
						
						
					} else {
						currentTag = RSSXMLTag.IGNORETAG;
					}
				} else if (eventType == XmlPullParser.TEXT) {
					String content = xpp.getText();
					content = content.trim();
//					Log.d("debug", content);
					if (currentElement != null && content.length() != 0) {
						switch (currentTag) {
							case TITLE:
								currentElement.title = content;
								break;
							case LINK:
								currentElement.clickUrl = content;
								break;
							case DATE:
//								currentElement.details = content;
								break;
							case DESCRIPTION:
								Spanned spanned = Html.fromHtml(content);
								processSpanned(spanned,currentElement);
								break;
							default:
								break;
						}
					}
				}

				eventType = xpp.next();
			}
			
		} catch (Exception e) {
			publishProgress(e.getMessage());
			e.printStackTrace();
		}
		
		return elementList;
	}

	private void processSpanned(Spanned spanned ,ListElement element) {

		ImageSpan[] imageSpans = spanned.getSpans(0, spanned.length(), ImageSpan.class);

		// try images (Smart AdServer blog
		if (imageSpans != null && imageSpans.length > 0) {
			element.thumbnailUrl = imageSpans[0].getSource();
			int spanEnd = spanned.getSpanEnd(imageSpans[0]);
			element.details = spanned.subSequence(spanEnd,spanned.length()-1).toString();
		} else {
			// try default String
			element.details = spanned.toString();
		}

		;

	}

}
