package com.smartadserver.android.sasnewsreader;

import android.graphics.Bitmap;
import android.graphics.drawable.BitmapDrawable;
import android.graphics.drawable.Drawable;
import android.os.Parcel;
import android.os.Parcelable;

import com.smartadserver.android.library.util.SASUtil;

/**
 * This class holds the data displayed by a cell of the ReclyclerView.
 * It serves as the base item of the data model.
 * It implements Parcelable to allow the serialization of the data model needed by the Activity state management.
 */
public class ListElement implements Parcelable {

	// video title
	public String title;
	// video details
	public String details;
	// Url to open on click
	public String clickUrl;
	// Label for action button
	public String actionLabel;
	// thumbnail Url
	public String thumbnailUrl;
	// only for temporary serialization purposes
	public Bitmap posterBitmap = null;

	/**
	 * Creator needed by Parcelable interface
	 */
	public static final Parcelable.Creator<ListElement> CREATOR
			= new Parcelable.Creator<ListElement>() {
		public ListElement createFromParcel(Parcel in) {
			return new ListElement(in);
		}

		public ListElement[] newArray(int size) {
			return new ListElement[size];
		}
	};

	@Override
	/**
	 * Needed by Parcelable interface
	 */
	public int describeContents() {
		return 0;
	}

	@Override
	/**
	 * Writes this ListElement to the specified Parcel
	 */
	public void writeToParcel(Parcel dest, int flags) {
		dest.writeString(title);
		dest.writeString(details);
		dest.writeString(clickUrl);
		dest.writeString(actionLabel);
		dest.writeString(thumbnailUrl);

		// try to serialize drawable if possible
		boolean hasBitmap = posterBitmap != null;
		dest.writeByte((byte)(hasBitmap?1:0));
		if (hasBitmap) {
			dest.writeParcelable(posterBitmap,flags);
		}

	}

	/**
	 * Creates a ListElement from a Parcel
	 */
	private ListElement(Parcel in) {
		title = in.readString();
		details = in.readString();
		clickUrl = in.readString();
		actionLabel = in.readString();
		thumbnailUrl = in.readString();

		boolean hasBitmap =  in.readByte()==1;
		if (hasBitmap) {
			posterBitmap = (Bitmap)in.readParcelable(null);
		}
	}


	// empty constructor for simple instantiation
	public ListElement() {
	}
}
