package com.smartadserver.android.sasnewsreader;


import java.io.InputStream;
import java.net.URL;
import java.util.ArrayList;

import android.app.Activity;
import android.graphics.drawable.Drawable;
import android.os.Bundle;
import android.support.v7.widget.LinearLayoutManager;
import android.support.v7.widget.RecyclerView;
import android.view.Menu;
import android.view.MenuItem;
import android.view.View;
import android.widget.ProgressBar;
import android.widget.Toast;

import com.smartadserver.android.library.model.SASNativeAdManager;
import com.smartadserver.android.library.model.SASNativeAdPlacement;
import com.smartadserver.android.library.util.SASConstants;

public class NewsViewActivity extends Activity {
	
	public static String TAG = NewsViewActivity.class.getSimpleName();

	private final static String FEED_LIST = "feedList";

    private RecyclerView mRecyclerViewList;
    private LinearLayoutManager mLayoutManager = null;
    
    ArrayList<ListElement> arrayList;
    ListAdapter listLayoutAdapter;
	private SASNativeAdManager[] nativeAdManagerPool;
	ProgressBar progressBar;

	@Override
	protected void onSaveInstanceState(Bundle outState) {
		super.onSaveInstanceState(outState);

		outState.putParcelableArrayList(FEED_LIST, arrayList);
	}

	@Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);

		arrayList = new ArrayList<ListElement>();

        mLayoutManager = new LinearLayoutManager(this);
        setContentView(R.layout.activity_recycler_view);

        bindViews();

		// create Native ad managers (one per placement)
        nativeAdManagerPool = new SASNativeAdManager[1];
        nativeAdManagerPool[0] = new SASNativeAdManager(this,SASNativeAdPlacement.ICON_COVER_TEXT_TEST_PLACEMENT);


        // now populate list with new items AND native ads
		if (savedInstanceState == null) {
			populateListFromRSS();
		} else {
			// restore saved list
			ArrayList<ListElement> elementList = savedInstanceState.getParcelableArrayList(FEED_LIST);
			arrayList.addAll(elementList);
			listLayoutAdapter.notifyDataSetChanged();
		}
    }
    
	/**
	 * 
	 */
	private void populateListFromRSS() {
		
		
		progressBar.setVisibility(View.VISIBLE);
		arrayList.clear();
		
		// instantiate custom AsyncTask to populate list
		FetchDataTask fetchDataTask = new FetchDataTask(nativeAdManagerPool) {

			@Override
			protected void onPostExecute(ArrayList<ListElement> result) {
				super.onPostExecute(result);

				arrayList.addAll(result);
				listLayoutAdapter.notifyDataSetChanged();
				progressBar.setVisibility(View.GONE);
			}

			@Override
			protected void onProgressUpdate(String... values) {
				super.onProgressUpdate(values);
				if (values.length == 0) {
					// this is normal case, no exception
					listLayoutAdapter.notifyDataSetChanged();
				} else {
					Toast.makeText(NewsViewActivity.this, values[0], Toast.LENGTH_LONG).show();
				}

			}
		};

//		fetchDataTask.execute("http://www.leparisien.fr/actualites-a-la-une.rss.xml");
		fetchDataTask.execute("http://blog.smartadserver.com/feed/");
	}

    @Override
    public void onDestroy() {
    	super.onDestroy();
    	for (int i = 0; i < nativeAdManagerPool.length; i++) {
    		nativeAdManagerPool[i].onDestroy();
    	}
    }

    private void bindViews() {
        mRecyclerViewList = (RecyclerView) findViewById(R.id.rv_list);
        mRecyclerViewList.setLayoutManager(mLayoutManager);
        listLayoutAdapter = new ListAdapter(arrayList,this);
        mRecyclerViewList.setAdapter(listLayoutAdapter);
        
        progressBar = (ProgressBar)findViewById(R.id.progressBar);
    }


    /**
	 * 
	 */
	@Override
	public boolean onCreateOptionsMenu(Menu menu) {
		// Inflate the menu; this adds items to the action bar if it is present.
		getMenuInflater().inflate(R.menu.news_list, menu);
		return true;
	}
	
	/**
	 * implement option menu actions
	 */
	public boolean onOptionsItemSelected(MenuItem item) {
	    // Handle item selection
	    switch (item.getItemId()) {
	    case R.id.action_reload:
	    	populateListFromRSS();
	        return true;
	    default:
	        return super.onOptionsItemSelected(item);
	    }
	}

}
