//
//  BannerInTableViewController.m
//  ObjCSample
//
//  Created by Julien Gomez on 29/04/2015.
//  Copyright (c) 2015 Smart AdServer. All rights reserved.
//

#import "BannerInTableViewController.h"
#import "SASAd.h"
#import "SASAdViewContainerCell.h"

#define kBanner1Position    4
#define kBanner2Position    14
#define kDefaultCellHeight  50


@interface BannerInTableViewController ()

@end

@implementation BannerInTableViewController

#pragma mark - Object lifecycle


- (void)viewDidLoad {
    [super viewDidLoad];
    
    // Initialize the refresh control.
    self.refreshControl = [[UIRefreshControl alloc] init];
    self.refreshControl.backgroundColor = [UIColor purpleColor];
    self.refreshControl.tintColor = [UIColor whiteColor];
    [self.refreshControl addTarget:self action:@selector(createBanners) forControlEvents:UIControlEventValueChanged];
    
    self.title = @"Pull to refresh";
    
    // Create the banners
    [self createBanners];
}


- (void)createBanners {
    // Remove banners if exist
    [self removeBanner:_banner1];
    [self removeBanner:_banner2];
    _banner1 = [self createBanner:@"548316"];
    _banner2 = [self createBanner:@"548804"];
}


- (SASTableBannerView *)createBanner:(NSString *) pageID {
    SASTableBannerView *banner = [[SASTableBannerView alloc] initWithFrame:CGRectMake(0, 0, CGRectGetWidth(self.view.frame), kDefaultCellHeight)];
    banner.delegate = self;
    banner.modalParentViewController = self;
    [banner loadFormatId:12161 pageId:pageID master:YES target:nil];
    
    return banner;
}


- (void)removeBanner:(SASTableBannerView *) banner {
    [banner removeFromSuperview];
    banner.loaded = NO;
}

#pragma mark - Table view data source

- (NSInteger)tableView:(UITableView *)tableView numberOfRowsInSection:(NSInteger)section {
    return 50;
}


- (CGFloat)tableView:(UITableView *)tableView heightForRowAtIndexPath:(NSIndexPath *)indexPath {
    if (kBanner1Position == indexPath.row) {
        return [_banner1 optimalAdViewHeightForContainer:tableView];
    } else if (kBanner2Position == indexPath.row) {
        return [_banner2 optimalAdViewHeightForContainer:tableView];
    } else {
        return kDefaultCellHeight;
    }
}


- (UITableViewCell *)tableView:(UITableView *)tableView cellForRowAtIndexPath:(NSIndexPath *)indexPath {
    if (kBanner1Position == indexPath.row) {
        return [SASAdViewContainerCell cellForAdView:_banner1 inTableView:tableView];
    } else if (kBanner2Position == indexPath.row) {
        return [SASAdViewContainerCell cellForAdView:_banner2 inTableView:tableView];
    } else {
        NSString *dummyCellIdentifier = @"dummyCell";
        UITableViewCell *cell = [tableView dequeueReusableCellWithIdentifier:dummyCellIdentifier];
        if (cell == nil) {
            cell = [[UITableViewCell alloc] initWithStyle:UITableViewCellStyleDefault reuseIdentifier:dummyCellIdentifier];
        }
        cell.textLabel.text = @"Lorem ipsum dolor sit amet";
        cell.accessoryType = UITableViewCellAccessoryDisclosureIndicator;
        return cell;
    }
}


- (void)tableView:(UITableView *)tableView didSelectRowAtIndexPath:(NSIndexPath *)indexPath {
    //Deselect the cell if it's an ad to avoid messing with the ad creative.
    if (kBanner1Position == indexPath.row || kBanner2Position == indexPath.row) {
        //Ad Cell was selected, nothing to do here.
    } else {
        //Your normal behavior on cell click like pushing a new VC
        [self pushNewViewController];
    }
    [tableView deselectRowAtIndexPath:indexPath animated:NO];
}


- (void)pushNewViewController {
    UIViewController *controller = [[UIViewController alloc] init];
    controller.navigationItem.title = @"Details";
    controller.view.backgroundColor = [UIColor whiteColor];
    UILabel *label = [[UILabel alloc] initWithFrame:controller.view.bounds];
    label.autoresizingMask = UIViewAutoresizingFlexibleWidth | UIViewAutoresizingFlexibleHeight;
    label.textAlignment = NSTextAlignmentCenter;
    label.text = @"Detail view controller";
    [controller.view addSubview:label];
    [self.navigationController pushViewController:controller animated:YES];
}

#pragma mark - SASAdView delegate

- (void)adView:(SASAdView *)adView didDownloadAd:(SASAd *)ad {
    [self.tableView reloadData];
}


- (void)adViewDidLoad:(SASAdView *)adView {
    NSLog(@"Banner has been loaded");
    SASTableBannerView *banner = (SASTableBannerView *)adView;
    banner.loaded = YES;
    
    if (_banner1.loaded && _banner2.loaded) {
        // Hide refresh control when both _banner1 & _banner2 are fully loaded
        [self.refreshControl endRefreshing];
    }
}


- (void)adView:(SASAdView *)adView didFailToLoadWithError:(NSError *)error {
    NSLog(@"Banner has failed to load with error: %@", [error description]);
    SASTableBannerView *banner = (SASTableBannerView *)adView;
    banner.loaded = YES;
    
    if (_banner1.loaded && _banner2.loaded) {
        // Hide refresh control when both _banner1 & _banner2 are fully loaded
        [self.refreshControl endRefreshing];
    }
}


- (void)adViewWillExpand:(SASAdView *)adView {
    NSLog(@"Banner will expand");
    [self setStatusBarHidden:YES];
}


- (void)adViewWillCloseExpand:(SASAdView *)adView {
    NSLog(@"Banner will close expand");
    [self setStatusBarHidden:NO];
}

#pragma mark - Status bar handling

- (void)setStatusBarHidden:(BOOL)hidden {
    _statusBarHidden = hidden;
    [self setNeedsStatusBarAppearanceUpdate];
}


- (BOOL)prefersStatusBarHidden {
    return _statusBarHidden || [super prefersStatusBarHidden];
}

@end
