//
//  ViewController.m
//  VASTVideoSample
//
//  Created by Clémence Laurent on 24/04/13.
//  Copyright (c) 2013 Smart AdServer. All rights reserved.
//

#import "ViewController.h"
#import "VideoElement.h"
#import "Constants.h"
#import "AppDelegate.h"


@implementation ViewController

#pragma mark - Deallocation

- (void)dealloc {
	[_videoElementsArray release], _videoElementsArray = nil;
	[super dealloc];
}


- (void)didReceiveMemoryWarning {
    [super didReceiveMemoryWarning];
	
	if (self.isViewLoaded && self.view.window == nil) {
		self.view = nil;
	}
	if (!self.isViewLoaded) {
		[_videoElementsArray release], _videoElementsArray = nil;
	}
}

#pragma mark - View life cycle

- (id)initWithStyle:(UITableViewStyle)style {
    self = [super initWithStyle:style];
    if (self) {
		
	}
    return self;
}


- (void)viewDidLoad {
    [super viewDidLoad];
	self.title = NSLocalizedString(kTitle, nil);
	
	[self populateArray];
	[self addDisplayModeButton];
	[self currentDisplayMode:SASMoviePlayerControlsDisplayModeDefault];
}


- (void)currentDisplayMode:(SASMoviePlayerControlsDisplayMode)displayMode {
	_currentDisplayMode = displayMode;
	
	switch (displayMode) {
		case SASMoviePlayerControlsDisplayModeDefault:
			[self.navigationItem.rightBarButtonItem setTitle:@"Default"];
			break;
		case SASMoviePlayerControlsDisplayModeInline:
			[self.navigationItem.rightBarButtonItem setTitle:@"Inline"];
			break;
		case SASMoviePlayerControlsDisplayModeFullscreenOnly:
			[self.navigationItem.rightBarButtonItem setTitle:@"Fullscreen"];
			break;
	}
}


- (void)addDisplayModeButton {
	
	UIBarButtonItem *displayModeButton = [[[UIBarButtonItem alloc] initWithTitle:@"" style:UIBarButtonItemStylePlain target:self action:@selector(displayModeButtonAction:)] autorelease];
	self.navigationItem.rightBarButtonItem = displayModeButton;
}


- (void)populateArray {
    VideoElement *bigBuckBunnyVideo = [[VideoElement alloc] initWithVideoPath:kBigBuckBunnyURL
																		title:kBigBuckBunnyTitle
																	  details:kBigBuckBunnyDetails
																   posterName:kBigBuckBunnyPosterName
																	  imdbURL:kBigBuckBunnyImdbURL];
	VideoElement *sintelVideo = [[VideoElement alloc] initWithVideoPath:kSintelURL
																  title:kSintelTitle
																details:kSintelDetails
															 posterName:kSintelPosterName
																imdbURL:kSintelImdbURL];

	VideoElement *elephantsDreamVideo = [[VideoElement alloc] initWithVideoPath:kElephantsDreamURL
																		  title:kElephantsDreamTitle
																		details:kElephantsDreamDetails
																	 posterName:kElephantsDreamPosterName
																		imdbURL:kElephantsDreamImdbURL];
	
	_videoElementsArray = [[NSArray alloc] initWithObjects:bigBuckBunnyVideo, sintelVideo, elephantsDreamVideo, nil];
}

#pragma mark - Table view data source

- (NSInteger)numberOfSectionsInTableView:(UITableView *)tableView {
    return 1;
}


- (NSInteger)tableView:(UITableView *)tableView numberOfRowsInSection:(NSInteger)section {
    return [_videoElementsArray count];
}


- (CGFloat)tableView:(UITableView *)tableView heightForRowAtIndexPath:(NSIndexPath *)indexPath {
	return kCellHeight;
}


- (UITableViewCell *)tableView:(UITableView *)tableView cellForRowAtIndexPath:(NSIndexPath *)indexPath {
    static NSString *CellIdentifier = @"VideoElementCell";
	UITableViewCell *cell = [tableView dequeueReusableCellWithIdentifier:CellIdentifier];

	if (!cell) {
        cell = [[UITableViewCell alloc] initWithStyle:UITableViewCellStyleSubtitle reuseIdentifier:CellIdentifier];
	}
	NSInteger row = [indexPath row];
	VideoElement *videoElement = [_videoElementsArray objectAtIndex:row];
    [self configureCell:cell withVideoElement:videoElement];
	
    return cell;
}


- (void)configureCell:(UITableViewCell *)cell withVideoElement:(VideoElement *)videoElement {
	
    cell.backgroundView = [[[UIImageView alloc] initWithImage:[UIImage imageNamed:kCellBackground]] autorelease];
    cell.selectedBackgroundView = [[[UIImageView alloc] initWithImage:[UIImage imageNamed:kCellSelectedBackground]]autorelease];
    
	cell.textLabel.text = videoElement.title;
    cell.textLabel.backgroundColor = [UIColor clearColor];
    
    cell.detailTextLabel.text = videoElement.details;
    cell.detailTextLabel.numberOfLines = 0;
    cell.detailTextLabel.backgroundColor = [UIColor clearColor];
    
    cell.imageView.image = [UIImage imageNamed:videoElement.posterName];
}

#pragma mark - Table view delegate

- (void)tableView:(UITableView *)tableView didSelectRowAtIndexPath:(NSIndexPath *)indexPath {
	NSInteger row = [indexPath row];
	VideoElement *videoElement = [_videoElementsArray objectAtIndex:row];

	if (_currentDisplayMode == SASMoviePlayerControlsDisplayModeDefault || _currentDisplayMode == SASMoviePlayerControlsDisplayModeInline) {
		DefaultAndInlineVideoViewController *defaultAndInlineVideoViewController = [[DefaultAndInlineVideoViewController alloc] initWithVideoURL:videoElement.videoURL imdbVideoURL:videoElement.imdbVideoURL displayMode:_currentDisplayMode];
		[self.navigationController pushViewController:defaultAndInlineVideoViewController animated:YES];
		[defaultAndInlineVideoViewController release];
	} else {
		
		// In case a fullscreen only, the view controller is placed in a modal view inside a new navigation control.
		FullscreenOnlyVideoViewController *fullscreenOnlyVideoViewController = [[FullscreenOnlyVideoViewController alloc] initWithVideoURL:videoElement.videoURL];
		UINavigationController *navigationController = [[UINavigationController alloc] initWithRootViewController:fullscreenOnlyVideoViewController];
		[navigationController setNavigationBarHidden:YES];
		[self.navigationController presentViewController:navigationController animated:YES completion:nil];
		[navigationController release];
		[fullscreenOnlyVideoViewController release];
	}
}

#pragma mark - Change display mode

- (void)displayModeButtonAction:(id)sender {
	
	UIActionSheet *actionSheet = [[UIActionSheet alloc] initWithTitle:@"Video player implementation" delegate:self cancelButtonTitle:@"Cancel" destructiveButtonTitle:nil otherButtonTitles:@"Default (with fullscreen button)", @"Inline (no fullscreen button)", @"Fullscreen only (done button)", nil];
	[actionSheet showFromBarButtonItem:sender animated:YES];
	[actionSheet release];
}


-(void)actionSheet:(UIActionSheet *)actionSheet clickedButtonAtIndex:(NSInteger)buttonIndex {

    if (buttonIndex != [actionSheet cancelButtonIndex]) {
		switch (buttonIndex) {
			case 0:
				[self currentDisplayMode:SASMoviePlayerControlsDisplayModeDefault];
				break;
			case 1:
				[self currentDisplayMode:SASMoviePlayerControlsDisplayModeInline];
				break;
			case 2:
				[self currentDisplayMode:SASMoviePlayerControlsDisplayModeFullscreenOnly];
				break;
		}
    }
}

@end
