//
//  SASAdBreakError.h
//  SASVideoSDK
//
//  Created by Erwan Aullas on 31/12/13.
//  Copyright (c) 2013 Smart AdServer. All rights reserved.
//

#import "SASAdError.h"


/** The SASVASTAdError class represents VAST ad errors occurring during ad sequence playback in SASMoviePlayerViewController.

 This indicates that there is no ad to display for the specified break type (preroll, midroll or postroll).
 
 To check for errors, implement the moviePlayerViewController:didFailToLoadAd: method of the SASMoviePlayerViewControllerDelegate delegate.
 If an error occurs, the error argument contains an SASError object so you can check if it's a SASAdBreakError instance 
 by checking its domain variable is kSASAdBreakErrorDomain.
 
 You can retrieve from the error's userInfos:
 - the description using NSLocalizedDescriptionKey
 - the break type of the failing ad (preroll, midroll or postroll) using kSASAdErrorBreakTypeKey
 
 You can also retrieve the VAST error code using the code variable.
 
 For more information, you can check the 'VAST errors management' topic in the documentation.
 
 */

@interface SASAdBreakError : SASAdError


/** Returns an initialized instance SASAdBreakError object initialized with the specified code, breaktype and message.
 
 @param code The code of the error.
 @param breakType The break type of the ad (preroll, midroll or postroll).
 @param message The message of the error.
 
 @return An initialized instance of SASAdBreakError.
 */

- (instancetype)initWithCode:(NSInteger)code breakType:(NSString *)breakType message:(NSString *)message;


/** Creates and initializes an SASAdBreakError object with the specified code, breaktype, insertionID and message.
 
 @param code The code of the error.
 @param breakType The break type of the ad (preroll, midroll or postroll).
 @param message The message of the error.
 
 @return An initialized instance of SASAdBreakError.
 
 */

+ (instancetype)adBreakErrorWithCode:(NSInteger)code breakType:(NSString *)breakType message:(NSString *)message;

@end
