//
//  SASAdPlayerError.h
//  SASVideoSDK
//
//  Created by Erwan Aullas on 31/12/13.
//  Copyright (c) 2013 Smart AdServer. All rights reserved.
//

#import "SASAdError.h"


/** The SASAdPlayerError class represents VAST ad errors occurring during ad sequence playback in SASMoviePlayerViewController.
 
 This indicates that there was an error with at least one of the ads to play.
 (This does not necessarily happen with all programmed ads for the specified break type (preroll, midroll or postroll) and there might still be ads to play).
 
 To check for errors, implement the moviePlayerViewController:didFailToLoadAd: method of the SASMoviePlayerViewControllerDelegate delegate.
 If an error occurs, the error argument contains an SASError object so you can check if it's a SASAdPlayerError instance
 by checking its domain variable is kSASAdPlayerErrorDomain.
 
 You can retrieve the error description from the error's userInfos using NSLocalizedDescriptionKey and the VAST error code using the code variable.
 
 For more information, you can check the 'VAST errors management' topic in the documentation.
 
 */

@interface SASAdPlayerError : SASAdError


/** Returns an initialized instance SASAdPlayerError object initialized with the specified code and message.
 
 @param code The code of the error.
 @param message The message of the error.
 
 @return An initialized instance of SASAdPlayerError.
 */

- (instancetype)initWithCode:(NSInteger)code message:(NSString *)message;


/** Creates and initializes an SASAdPlayerError object with the specified code, breaktype, insertionID and message.
 
 @param code The code of the error.
 @param message The message of the error.
 
 @return An initialized instance of SASAdPlayerError.
 
 */

+ (instancetype)adPlayerErrorWithCode:(NSInteger)code message:(NSString *)message;

@end
