//
//  SASMoviePlayerController.h
//  SASVideoSDK
//
//  Created by Clémence Laurent on 09/08/13.
//  Copyright (c) 2013 Smart AdServer. All rights reserved.
//

#import <UIKit/UIKit.h>
#import <MediaPlayer/MediaPlayer.h>


typedef NS_ENUM(NSInteger, SASMoviePlayerControlsDisplayMode) {
	SASMoviePlayerControlsDisplayModeDefault,
	SASMoviePlayerControlsDisplayModeInline,
	SASMoviePlayerControlsDisplayModeFullscreenOnly,
};

@class SASPlayerControlsView;


/** The SASMoviePlayerController class is used to manage the playback of a video from a file or a network stream.
 
 An instance of this class is created and managed by the SASMoviePlayerViewController instance in order to
 display the content video.
 
 The SASMoviePlayerController class inherits from the MPMoviePlayerController class, which allows you to use any of its method.
 
 */

@interface SASMoviePlayerController : MPMoviePlayerController


/** Whether controls on content video should be displayed (they will still be automatically hidden after a small period of time.
 
 This property only works for content video, not for ads videos.
 
 */

@property (nonatomic, assign, getter = areControlsEnabled) BOOL controlsEnabled;


/** The DONE button is disabled during preroll if YES, shown otherwise. The default value is NO.
 
 This property only works in SASMoviePlayerControlsDisplayModeFullscreenOnly display mode.
 
 */

@property (nonatomic, assign, getter = isPrerollDoneDisabled) BOOL prerollDoneDisabled;


/** The DONE button is disabled during midroll if YES, shown otherwise. The default value is NO.
 
 This property only works in SASMoviePlayerControlsDisplayModeFullscreenOnly display mode.
 
 */

@property (nonatomic, assign, getter = isMidrollDoneDisabled) BOOL midrollDoneDisabled;


/** The DONE button is disabled during postroll if YES, shown otherwise. The default value is NO.
 
 This property only works in SASMoviePlayerControlsDisplayModeFullscreenOnly display mode.
 
 */

@property (nonatomic, assign, getter = isPostrollDoneDisabled) BOOL postrollDoneDisabled;


/** Forces the state of the fullscreen button to a given value.
 The default value is NO.
 
 @param isFullscreen YES if the fullscreen button should be displayed as if the player is in fullscreen mode, NO otherwise.
 
 */

- (void)updateFullscreenButtonState:(BOOL)isFullscreen;


/** The mode that will be used to display the controls. Valid values are:
 
	typedef enum {
		SASMoviePlayerControlsDisplayModeDefault,
		SASMoviePlayerControlsDisplayModeInline,
		SASMoviePlayerControlsDisplayModeFullscreenOnly,
	} SASMoviePlayerControlsDisplayMode;

 `SASMoviePlayerControlsDisplayModeDefault`
 
 Default controls layout. Display a fullscreen button and no navigation bar.
 
 Available in SASVideoSDK 1.0 and later.
 
 `SASMoviePlayerControlsDisplayModeInline`
 
 Display no fullscreen button and no navigation bar.
 
 Available in SASVideoSDK 1.0 and later.
 
 `SASMoviePlayerControlsDisplayModeFullscreenOnly`
 
 Display a navigation bar with a 'Done' button (that will send an exit fullscreen notification if clicked). Recommended display mode for modal video players.
 
 Available in SASVideoSDK 1.0 and later.
 
 */

@property (nonatomic, readonly) SASMoviePlayerControlsDisplayMode displayMode;

@end
