//
//  SASMoviePlayerViewControllerDelegate.h
//  SASVideoSDK
//
//  Created by Loïc GIRON DIT METAZ on 24/09/13.
//  Copyright (c) 2013 Smart AdServer. All rights reserved.
//


@class SASMoviePlayerViewController, SASAdError;


/** The delegate of a SASMoviePlayerViewController object must adopt the SASMoviePlayerViewControllerDelegate protocol.
 
 The protocol methods allow the delegate to be aware of the ad-related events.
 
 */

@protocol SASMoviePlayerViewControllerDelegate <NSObject>

@optional

/** Notifies the delegate that the ad could not be downloaded and displayed properly.
 
 With this method you are informed that the ad could not be downloaded and you can take the appropriate decision (save state, launch your introduction video, ...).
 
 You can retrieve the error domain of your error. It can have the following values:

 `kSASAdPlayerErrorDomain`
 
 The error is a VAST from the ad player.
 
 `kSASVASTAdErrorDomain`

 The error is a VAST ad error.
 
 `kSASAdBreakErrorDomain`

 The error is a VAST from an ad break event.
 
 
 You can retrieve the error infos from the userInfos dictionary with the following keys (for SASVASTAdError and SASAdBreakError errors):
 
 `kSASAdErrorBreakTypeKey`
 
 The break type of the ad error.
 
 `kSASAdErrorInsertionIDKey`

 The insertion ID of the ad error.

 Note that if the error code is equal to `SASErrorCodeVASTError`, you can retrieve the exact VAST error code and the ID of the responsible insertion
 using `SASErrorVASTErrorParameterVASTErrorCode` & `SASErrorVASTErrorParameterInsertionID` keys on the error's userInfo.
 
 The complete list of VAST error code is available in the official VAST 3.0 documentation: http://www.iab.net/media/file/VASTv3.0.pdf
 
 @param moviePlayerViewController A movie player view controller object informing the delegate about the ad beeing clicked.
 @param error An error informing the delegate about the cause of the failure.
 
 */

- (void)moviePlayerViewController:(SASMoviePlayerViewController *)moviePlayerViewController didFailToLoadAd:(SASAdError *)error;


/** Notifies the delegate that an ad action has been made (for example the user clicked the ad).
 
 With this method you are informed of the user's action, and you can take the appropriate decision (save state, launch your introduction video, …).
 
 @param moviePlayerViewController A movie player view controller object informing the delegate about the ad beeing clicked.
 @param exit Whether the user chooses to leave the app.
 
 */

- (void)moviePlayerViewController:(SASMoviePlayerViewController *)moviePlayerViewController willPerformActionWithExit:(BOOL)exit;


/** Notifies the delegate that a modal view will appear to display the ad's redirect URL web page if appropriate.
 
 @param moviePlayerViewController The instance of SASMoviePlayerViewController displaying the modal view.
 
 */

- (void)moviePlayerViewControllerWillPresentModalView:(SASMoviePlayerViewController *)moviePlayerViewController;


/** Notifies the delegate that the modal view will be dismissed.
 
 @param moviePlayerViewController The instance of SASMoviePlayerViewController closing the modal view.
 
 */

- (void)moviePlayerViewControllerWillDismissModalView:(SASMoviePlayerViewController *)moviePlayerViewController;

@end
