//
//  SASPlayerAdConfig.h
//  SASVideoSDK
//
//  Created by Loïc GIRON DIT METAZ on 25/09/13.
//  Copyright (c) 2013 Smart AdServer. All rights reserved.
//

#import "SASPlayerConfig.h"


@class SASPlayerMidrollConfig;


/** The SASPlayerAdConfig class is used to configure ad call parameters.
 
 An instance of this class must be passed as parameter of a SASMoviePlayerViewController object in order to
 display one or several ads during video playback.
 
 The SASPlayerAdConfig can be instantiated using a generic formatID which will be used for all prerolls, midrolls
 and postrolls (in this case a configuration must be provided for the midroll), or it can be instantiated without
 any formatID: in this case, you must add the preroll/midroll/postroll formatID manually using setPrerollWithFormatID:,
 setMidrollWithFormatID:midrollConfig: and setPostrollWithFormatID:.
 
 */

@interface SASPlayerAdConfig : SASPlayerConfig

/** Initializes a SASPlayerAdConfig object.
 
 @param networkID The networkID that will be used for ad calls.
 @param siteID The siteID that will be used for ad calls.
 @param pageID The pageID that will be used for ad calls.
 @param formatID The formatID that will be used for preroll, midroll and postroll ad calls.
 @param midrollConfig An instance of SASPlayerMidrollConfig used to set up position of midrolls inside the content video.
 @param target The targeting string that will be sent during ad calls (can be nil or empty if not needed).
 
 @return An initialized instance of SASPlayerAdConfig.
 
 */

- (instancetype)initWithNetworkID:(NSInteger)networkID siteID:(NSInteger)siteID pageID:(NSString *)pageID formatID:(NSInteger)formatID midrollConfig:(SASPlayerMidrollConfig *)midrollConfig target:(NSString *)target;


/** Initializes a SASPlayerAdConfig object.
 
 @param networkID The networkID that will be used for the ad calls.
 @param siteID The siteID that will be used for the ad calls.
 @param pageID The pageID that will be used for the ad calls.
 @param target The targeting string that will be sent during ad calls (can be nil or empty if not needed).
 
 @return An initialized instance of SASPlayerAdConfig.
 
 */

- (instancetype)initWithNetworkID:(NSInteger)networkID siteID:(NSInteger)siteID pageID:(NSString *)pageID target:(NSString *)target;


/** Initializes a SASPlayerAdConfig object.
 
 @param networkID The networkID that will be used for the ad calls.
 @param siteID The siteID that will be used for the ad calls.
 @param pageID The pageID that will be used for the ad calls.
 @param formatID The formatID that will be used for preroll, midroll and postroll ad calls.
 @param midrollConfig An instance of SASPlayerMidrollConfig used to set up position of midrolls inside the content video.
 @param target The targeting string that will be sent during ad calls (can be nil or empty if not needed).
 @param timeout The timeout used for ad calls (in seconds).
 
 @return An initialized instance of SASPlayerAdConfig.
 
 */

- (instancetype)initWithNetworkID:(NSInteger)networkID siteID:(NSInteger)siteID pageID:(NSString *)pageID formatID:(NSInteger)formatID midrollConfig:(SASPlayerMidrollConfig *)midrollConfig target:(NSString *)target timeout:(NSTimeInterval)timeout;


/** Initializes a SASPlayerAdConfig object.
 
 @param networkID The networkID that will be used for the ad calls.
 @param siteID The siteID that will be used for the ad calls.
 @param pageID The pageID that will be used for the ad calls.
 @param target The targeting string that will be sent during ad calls (can be nil or empty if not needed).
 @param timeout The timeout used for ad calls (in seconds).
 
 @return An initialized instance of SASPlayerAdConfig.
 
 */

- (instancetype)initWithNetworkID:(NSInteger)networkID siteID:(NSInteger)siteID pageID:(NSString *)pageID target:(NSString *)target timeout:(NSTimeInterval)timeout;


/** Returns an initialized instance of SASPlayerAdConfig.
 
 @param networkID The networkID that will be used for ad calls.
 @param siteID The siteID that will be used for ad calls.
 @param pageID The pageID that will be used for ad calls.
 @param formatID The formatID that will be used for preroll, midroll and postroll ad calls.
 @param midrollConfig An instance of SASPlayerMidrollConfig used to set up position of midrolls inside the content video.
 @param target The targeting string that will be sent during ad calls (can be nil or empty if not needed).
 
 @return An initialized instance of SASPlayerAdConfig.
 
 */

+ (instancetype)adConfigWithNetworkID:(NSInteger)networkID siteID:(NSInteger)siteID pageID:(NSString *)pageID formatID:(NSInteger)formatID midrollConfig:(SASPlayerMidrollConfig *)midrollConfig target:(NSString *)target;


/** Returns an initialized instance of SASPlayerAdConfig.
 
 @param networkID The networkID that will be used for the ad calls.
 @param siteID The siteID that will be used for the ad calls.
 @param pageID The pageID that will be used for the ad calls.
 @param target The targeting string that will be sent during ad calls (can be nil or empty if not needed).
 
 @return An initialized instance of SASPlayerAdConfig.
 
 */

+ (instancetype)adConfigWithNetworkID:(NSInteger)networkID siteID:(NSInteger)siteID pageID:(NSString *)pageID target:(NSString *)target;


/** Returns an initialized instance of SASPlayerAdConfig.
 
 @param networkID The networkID that will be used for the ad calls.
 @param siteID The siteID that will be used for the ad calls.
 @param pageID The pageID that will be used for the ad calls.
 @param formatID The formatID that will be used for preroll, midroll and postroll ad calls.
 @param midrollConfig An instance of SASPlayerMidrollConfig used to set up position of midrolls inside the content video.
 @param target The targeting string that will be sent during ad calls (can be nil or empty if not needed).
 @param timeout The timeout used for ad calls (in seconds).
 
 @return An initialized instance of SASPlayerAdConfig.
 
 */

+ (instancetype)adConfigWithNetworkID:(NSInteger)networkID siteID:(NSInteger)siteID pageID:(NSString *)pageID formatID:(NSInteger)formatID midrollConfig:(SASPlayerMidrollConfig *)midrollConfig target:(NSString *)target timeout:(NSTimeInterval)timeout;


/** Returns an initialized instance of SASPlayerAdConfig.
 
 @param networkID The networkID that will be used for the ad calls.
 @param siteID The siteID that will be used for the ad calls.
 @param pageID The pageID that will be used for the ad calls.
 @param target The targeting string that will be sent during ad calls (can be nil or empty if not needed).
 @param timeout The timeout used for ad calls (in seconds).
 
 @return An initialized instance of SASPlayerAdConfig.
 
 */

+ (instancetype)adConfigWithNetworkID:(NSInteger)networkID siteID:(NSInteger)siteID pageID:(NSString *)pageID target:(NSString *)target timeout:(NSTimeInterval)timeout;


/** Sets the formatID used for preroll ad calls.
 
 @param prerollFormatID The formatID that will be used for prerolls.
 
 */

- (void)setPrerollWithFormatID:(NSInteger)prerollFormatID;


/** Sets the formatID used for midroll ad calls.
 
 @param midrollFormatID The formatID that will be used for midrolls.
 @param midrollConfig An instance of SASPlayerMidrollConfig used to set up position of midrolls inside the content video.
 
 */

- (void)setMidrollWithFormatID:(NSInteger)midrollFormatID midrollConfig:(SASPlayerMidrollConfig *)midrollConfig;


/** Sets the formatID used for postroll ad calls.
 
 @param postrollFormatID The formatID that will be used for postrolls.
 
 */

- (void)setPostrollWithFormatID:(NSInteger)postrollFormatID;


/** Set extra parameters that will be sent to the ad player. This can be useful for syndication purpose (see documentation).
 
 @param extraParameters The extra parameters to be sent to the ad player. It must be a dictionary using only strings (as keys and objects).
 
 */

- (void)setExtraParameters:(NSDictionary *)extraParameters;

@end
