//
//  SASPlayerDisplayConfig.h
//  SASVideoSDK
//
//  Created by Loïc GIRON DIT METAZ on 26/09/13.
//  Copyright (c) 2013 Smart AdServer. All rights reserved.
//

#import "SASPlayerConfig.h"


/** The SASPlayerDisplayConfig class is used to configure ad call parameters.
 
 An instance of this class must be passed as a parameter of a SASMoviePlayerViewController object in order to
 display one or several ads during video playback.
 
 The SASPlayerDisplayConfig can be instantiated using a generic adCountdownMessage which will be used for all prerolls,
 midrolls and postrolls, or it can be instantiated without any adCountdownMessage:
 
 - A default one is assigned for all formats
 - You can add the preroll/midroll/postroll ad countdown message manually using -setPrerollAdCountdownMessage:,
 -setMidrollAdCountdownMessage: and -setPostrollAdCountdownMessage:.
 
 */

@interface SASPlayerDisplayConfig : SASPlayerConfig

/** Initializes a SASPlayerDisplayConfig object.
 The parameters are set for all ads using the same display configuration, that is prerolls, midrolls and postrolls.
 If you want a different message for each of those formats, you can use -setPrerollAdCountdownMessage:, -setMidrollAdCountdownMessage: and -setPostrollAdCountdownMessage:.
 
 @param adCountdownMessage The ad countdown message that will be displayed at the bottom of the view.
 @param skipMessage The message that will be displayed before the appearance of the skip button.
 @param skipButtonLabel The label that will be displayed in the button for skipping the ad.
 @param infoButtonLabel The label that will be displayed in the button for opening the click URL in the modal view.
 @param doneButtonLabel The label that will be displayed in the button for closing the player (in fullscreen only display mode).
 
 @return An initialized instance of SASPlayerDisplayConfig.
 
 */

- (instancetype)initWithAdCountdownMessage:(NSString *)adCountdownMessage skipMessage:(NSString *)skipMessage skipButtonLabel:(NSString *)skipButtonLabel infoButtonLabel:(NSString *)infoButtonLabel doneButtonLabel:(NSString *)doneButtonLabel;


/** Returns an initialized instance of SASPlayerDisplayConfig.
 The parameters are set for all ads using the same display configuration, that is prerolls, midrolls and postrolls.
 If you want a different message for each of those formats, you can use -setPrerollAdCountdownMessage:, -setMidrollAdCountdownMessage: and -setPostrollAdCountdownMessage:.

 @param adCountdownMessage The ad countdown message that will be displayed at the bottom of the view.
 @param skipMessage The message that will be displayed before the appearance of the skip button.
 @param skipButtonLabel The label that will be displayed in the button for skipping the ad.
 @param infoButtonLabel The label that will be displayed in the button for opening the click URL in the modal view.
 @param doneButtonLabel The label that will be displayed in the button for closing the player (in fullscreen only display mode).
 
 @return An initialized instance of SASPlayerDisplayConfig.
 
 */

+ (instancetype)displayConfigWithAdCountdownMessage:(NSString *)adCountdownMessage skipMessage:(NSString *)skipMessage skipButtonLabel:(NSString *)skipButtonLabel infoButtonLabel:(NSString *)infoButtonLabel doneButtonLabel:(NSString *)doneButtonLabel;


/** Sets the message used for the preroll ad countdown.
 
 @param prerollAdCountdownMessage The message that will be used for the preroll ad countdown.
 
 */

- (void)setPrerollAdCountdownMessage:(NSString *)prerollAdCountdownMessage;


/** Sets the message used for the midroll ad countdown.
 
 @param midrollAdCountdownMessage The message that will be used for the midroll ad countdown.
 
 */

- (void)setMidrollAdCountdownMessage:(NSString *)midrollAdCountdownMessage;


/** Sets the message used for the postroll ad countdown.
 
 @param postrollAdCountdownMessage The message that will be used for the postroll ad countdown.
 
 */

- (void)setPostrollAdCountdownMessage:(NSString *)postrollAdCountdownMessage;


/** Sets (or replaces) the label used for the 'done' button.
 This parameter is only available in SASMoviePlayerControlsDisplayModeFullscreenOnly display mode.
 
 @param doneButtonLabel The label that will be displayed in the button to close the player.
 
 */

- (void)setDoneButtonLabel:(NSString *)doneButtonLabel;

@end
