//
//  SASVASTAdError.h
//  SASVideoSDK
//
//  Created by Erwan Aullas on 31/12/13.
//  Copyright (c) 2013 Smart AdServer. All rights reserved.
//

#import "SASAdError.h"


/** The SASVASTAdError class represents VAST ad errors occurring during ad sequence playback in SASMoviePlayerViewController.
 
 This indicates that there was an error with at least one of the ads to play.
 (This does not necessarily happen with all programmed ads for the specified break type (preroll, midroll or postroll) and there might still be ads to play).
 
 To check for errors, implement the moviePlayerViewController:didFailToLoadAd: method of the SASMoviePlayerViewControllerDelegate delegate.
 If an error occurs, the error argument contains an SASError object so you can check if it's a SASVASTAdError instance
 by checking its domain variable is kSASVASTAdErrorDomain.
 
 You can retrieve from the error's userInfos:
 - the description using NSLocalizedDescriptionKey
 - the break type of the failing ad (preroll, midroll or postroll) using kSASAdErrorBreakTypeKey
 - the insertion ID of the failing ad using kSASAdErrorInsertionIDKey
 
 You can also retrieve the VAST error code using the code variable.
 
 For more information, you can check the 'VAST errors management' topic in the documentation.
 
 */

@interface SASVASTAdError : SASAdError


/** Returns an initialized instance SASVASTAdError object initialized with the specified code, breaktype, insertionID and message.
 
 @param code The code of the error.
 @param breakType The break type of the ad (preroll, midroll or postroll).
 @param insertionID The insertionID of the ad.
 @param message The message of the error.
 
 @return An initialized instance of SASAdError.
 */

- (instancetype)initWithCode:(NSInteger)code breakType:(NSString *)breakType insertionID:(NSString *)insertionID message:(NSString *)message;


/** Creates and initializes an SASAdError object with the specified code, breaktype, insertionID and message.
 
 @param code The code of the error.
 @param breakType The break type of the ad (preroll, midroll or postroll).
 @param insertionID The insertionID of the ad.
 @param message The message of the error.
 
 @return An initialized instance of SASAdError.
 
 */

+ (instancetype)VASTAdErrorWithCode:(NSInteger)code breakType:(NSString *)breakType insertionID:(NSString *)insertionID message:(NSString *)message;

@end
